@@ -34,13 +34,15 @@
 #include "backends/mixer_backend.h"
 #include "core/MasterControl.h"
 #include "mixset.h"
+#include "core/GlobalConfig.h"
 #include "core/mixdevice.h"
 #include "dbus/dbusmixerwrapper.h"
+#include "kmixcore_export.h"
 
 class Volume;
 class KConfig;
 
-class Mixer : public QObject
+class KMIXCORE_EXPORT Mixer : public QObject
 {
       Q_OBJECT
 
@@ -116,8 +118,11 @@ public:
     // Returns the name of the driver, e.g. "OSS" or "ALSA0.9"
     static QString driverName(int num);
 
-    static void setBeepOnVolumeChange(bool m_beepOnVolumeChange);
-    static bool getBeepOnVolumeChange() { return m_beepOnVolumeChange; }
+    static bool getBeepOnVolumeChange()
+    {
+    	GlobalConfigData& gcd = GlobalConfig::instance().data;
+    	return gcd.beepOnVolumeChange;
+    }
 
     /**
      * Returns an unique ID of the Mixer. It currently looks like "<soundcard_descr>::<hw_number>:<driver>"
@@ -150,7 +155,8 @@ public:
     static shared_ptr<MixDevice> getGlobalMasterMD(bool fallbackAllowed);
     static Mixer* getGlobalMasterMixer();
     static Mixer* getGlobalMasterMixerNoFalback();
-    static MasterControl& getGlobalMasterPreferred();
+    static MasterControl& getGlobalMasterPreferred(bool fallbackAllowed = true);
+    QString getRecommendedDeviceId();
 
     /******************************************
     The recommended master of this Mixer.
